==> opennms-webapp-1.3.3-sources.jar: org/opennms/web/controller/CategoryStatusController.java <==
//
// This file is part of the OpenNMS(R) Application.
//
// OpenNMS(R) is Copyright (C) 2006 The OpenNMS Group, Inc.  All rights reserved.
// OpenNMS(R) is a derivative work, containing both original code, included code and modified
// code that was published under the GNU General Public License. Copyrights for modified 
// and included code are below.
//
// OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
//
// Original code base Copyright (C) 1999-2001 Oculan Corp.  All rights reserved.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// For more information contact:
// OpenNMS Licensing       <license@opennms.org>
//     http://www.opennms.org/
//     http://www.opennms.com/
//

package org.opennms.web.controller;

import java.util.Collection;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.opennms.web.svclayer.catstatus.model.StatusSection;
import org.opennms.web.svclayer.catstatus.support.DefaultCategoryStatusService;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.AbstractController;

/**
 * 
 * @author fastjay
 *
 */
public class CategoryStatusController extends AbstractController {

	DefaultCategoryStatusService m_categorystatusservice;
	Collection <StatusSection>statusSections;
	
	@Override
	protected ModelAndView handleRequestInternal(HttpServletRequest arg0,
			HttpServletResponse arg1) throws Exception {
		
		statusSections = m_categorystatusservice.getCategoriesStatus(); 
		ModelAndView modelAndView = new ModelAndView("displayCategoryStatus","statusTree",statusSections);
		
		return modelAndView;
	}

	
	public void setCategoryStatusService(DefaultCategoryStatusService categoryStatusService){
		
		m_categorystatusservice = categoryStatusService;
		
		
	}
	
}

==> opennms-webapp-1.8.13-sources.jar: org/opennms/web/controller/CategoryStatusController.java <==
//
// This file is part of the OpenNMS(R) Application.
//
// OpenNMS(R) is Copyright (C) 2006 The OpenNMS Group, Inc.  All rights reserved.
// OpenNMS(R) is a derivative work, containing both original code, included code and modified
// code that was published under the GNU General Public License. Copyrights for modified 
// and included code are below.
//
// OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
//
// Original code base Copyright (C) 1999-2001 Oculan Corp.  All rights reserved.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// For more information contact:
// OpenNMS Licensing       <license@opennms.org>
//     http://www.opennms.org/
//     http://www.opennms.com/
//

package org.opennms.web.controller;

import java.util.Collection;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.opennms.web.svclayer.catstatus.model.StatusSection;
import org.opennms.web.svclayer.catstatus.support.DefaultCategoryStatusService;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.AbstractController;

/**
 * <p>CategoryStatusController class.</p>
 *
 * @author fastjay
 * @version $Id: $
 * @since 1.8.1
 */
public class CategoryStatusController extends AbstractController {

	DefaultCategoryStatusService m_categorystatusservice;
	Collection <StatusSection>statusSections;
	
	/** {@inheritDoc} */
	@Override
	protected ModelAndView handleRequestInternal(HttpServletRequest arg0,
			HttpServletResponse arg1) throws Exception {
		
		statusSections = m_categorystatusservice.getCategoriesStatus(); 
		ModelAndView modelAndView = new ModelAndView("displayCategoryStatus","statusTree",statusSections);
		
		return modelAndView;
	}

	
	/**
	 * <p>setCategoryStatusService</p>
	 *
	 * @param categoryStatusService a {@link org.opennms.web.svclayer.catstatus.support.DefaultCategoryStatusService} object.
	 */
	public void setCategoryStatusService(DefaultCategoryStatusService categoryStatusService){
		
		m_categorystatusservice = categoryStatusService;
		
		
	}
	
}
